#!/usr/bin/env python3
import sentry_sdk
from sentry_sdk.integrations.flask import FlaskIntegration
from flask import Flask
import os
from db import redis_client
from views import ConsumersView, LogView, SyncView

"""
Main Flask RESTful API
"""

__author__ = "@tormakris"
__copyright__ = "Copyright 2020, GoldenPogácsa Team"
__module_name__ = "app"
__version__text__ = "1"

# Setup sentry
SENTRY_DSN = os.environ.get("SENTRY_DSN")
if SENTRY_DSN:
    sentry_sdk.init(
        dsn = SENTRY_DSN,
        integrations = [FlaskIntegration()],
        send_default_pii = True,
        release = os.environ.get('RELEASE_ID', 'test'),
        environment = os.environ.get('RELEASEMODE', 'dev')
    )

app = Flask(__name__)
app.config['REDIS_URL'] = os.environ['REDIS_URL']
app.config['LOCAL_UUID'] = os.environ['LOCAL_UUID']
app.config['CUSTOMER_TIMEOUT'] = int(os.environ.get('CUSTOMER_TIMEOUT', 30))
app.config['PRODUCER_TIMEOUT'] = int(os.environ.get('PRODUCER_TIMEOUT', 60))

redis_client.init_app(app)

for view in [ConsumersView, LogView, SyncView]:
    view.register(app, trailing_slash = False)

if __name__ == "__main__":
    app.run(debug = True)
